@@ -42,7 +42,10 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 	public static final String OPTION_ENABLE_DENY_AND_EXCEPTIONS_IN_POLICIES = "enableDenyAndExceptionsInPolicies";
 	public static final String OPTION_ENABLE_IMPLICIT_CONDITION_EXPRESSION   = "enableImplicitConditionExpression";
-	public static final String OPTION_ENABLE_TAG_BASED_POLICIES = "enableTagBasedPolicies";
+	public static final String OPTION_ENABLE_TAG_BASED_POLICIES              = "enableTagBasedPolicies";
+	public static final String OPTION_RRN_RESOURCE_SEP_CHAR                  = "rrnResourceSepChar";
+
+	public static final char DEFAULT_RRN_RESOURCE_SEP_CHAR = '/';
 
 	private String                         name;
 	private String                         displayName;
@@ -1710,8 +1713,8 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		public Boolean getIsValidLeaf() { return isValidLeaf; }
 
 		public void setIsValidLeaf(Boolean isValidLeaf) {
-		    this.isValidLeaf = isValidLeaf;
-        }
+			this.isValidLeaf = isValidLeaf;
+		}
 
 		public void dedupStrings(Map<String, String> strTbl) {
 			name                   = StringUtil.dedupString(name, strTbl);
@@ -1932,12 +1935,12 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 					return false;
 			} else if (!accessTypeRestrictions.equals(other.accessTypeRestrictions))
 				return false;
-            if (isValidLeaf == null) {
-                if (other.isValidLeaf != null)
-                    return false;
-            } else if (!isValidLeaf.equals(other.isValidLeaf))
-                return false;
-            return true;
+			if (isValidLeaf == null) {
+				if (other.isValidLeaf != null)
+					return false;
+			} else if (!isValidLeaf.equals(other.isValidLeaf))
+					return false;
+			return true;
 		}
 		
 	}
