@@ -19,6 +19,8 @@
 
 package org.apache.ranger.plugin.policyengine;
 
+import org.apache.ranger.plugin.model.RangerInlinePolicy;
+
 import java.util.Collections;
 import java.util.Date;
 import java.util.List;
@@ -72,6 +74,10 @@ public interface RangerAccessRequest {
 		return Collections.emptyMap();
 	}
 
+	default RangerInlinePolicy getInlinePolicy() {
+		return null;
+	}
+
 	enum ResourceMatchingScope { SELF, SELF_OR_DESCENDANTS }
 
 	enum ResourceElementMatchingScope { SELF, SELF_OR_CHILD, SELF_OR_PREFIX }
