@@ -19,6 +19,8 @@
 
 package org.apache.ranger.plugin.policyengine;
 
+import org.apache.ranger.plugin.model.RangerInlinePolicy;
+
 import java.util.Collections;
 import java.util.Date;
 import java.util.List;
@@ -110,4 +112,8 @@ public class RangerAccessRequestReadOnly implements RangerAccessRequest {
 	@Override
 	public String getClusterType() {  return source.getClusterType();	}
 
+	@Override
+	public RangerInlinePolicy getInlinePolicy() {
+		return source.getInlinePolicy();
+	}
 }
