@@ -21,7 +21,7 @@ package org.apache.ranger.plugin.policyengine;
 
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.collections.MapUtils;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.ranger.authorization.utils.JsonUtils;
 import org.apache.ranger.plugin.contextenricher.RangerAbstractContextEnricher;
 import org.apache.ranger.plugin.contextenricher.RangerContextEnricher;
@@ -191,7 +191,7 @@ public class RangerPolicyRepository {
         this.componentServiceDef  = this.serviceDef = ServiceDefUtil.normalize(servicePolicies.getServiceDef());
         this.zoneName             = zoneName;
         this.appId                = pluginContext.getConfig().getAppId();
-        this.options              = new RangerPolicyEngineOptions(pluginContext.getConfig().getPolicyEngineOptions());
+        this.options              = new RangerPolicyEngineOptions(pluginContext.getConfig().getPolicyEngineOptions(), new RangerServiceDefHelper(serviceDef, false));
         this.pluginContext        = pluginContext;
 
         if (StringUtils.isEmpty(zoneName)) {
@@ -230,8 +230,6 @@ public class RangerPolicyRepository {
             LOG.debug("RangerPolicyRepository : building policy-repository for service[" + serviceName + "], and zone:[" + zoneName + "] with auditMode[" + auditModeEnum + "]");
         }
 
-        init(options);
-
         if (StringUtils.isEmpty(zoneName)) {
             this.contextEnrichers = buildContextEnrichers(options);
             this.auditPolicyEvaluators = buildAuditPolicyEvaluators(servicePolicies.getServiceConfig());
@@ -240,6 +238,8 @@ public class RangerPolicyRepository {
             this.auditPolicyEvaluators = Collections.emptyList();
         }
 
+        init(options);
+
         if (options.disableTrieLookupPrefilter) {
             policyResourceTrie      = null;
             dataMaskResourceTrie    = null;
@@ -263,7 +263,7 @@ public class RangerPolicyRepository {
         this.serviceDef           = ServiceDefUtil.normalizeAccessTypeDefs(ServiceDefUtil.normalize(tagPolicies.getServiceDef()), componentServiceDef.getName());
         this.componentServiceDef  = componentServiceDef;
         this.appId                = pluginContext.getConfig().getAppId();
-        this.options              = new RangerPolicyEngineOptions(pluginContext.getConfig().getPolicyEngineOptions());
+        this.options              = new RangerPolicyEngineOptions(pluginContext.getConfig().getPolicyEngineOptions(), new RangerServiceDefHelper(serviceDef, false));
         this.pluginContext        = pluginContext;
         this.policies             = normalizeAndPrunePolicies(tagPolicies.getPolicies(), componentServiceDef.getName());
         this.policyVersion        = tagPolicies.getPolicyVersion() != null ? tagPolicies.getPolicyVersion() : -1;
@@ -284,8 +284,6 @@ public class RangerPolicyRepository {
             LOG.debug("RangerPolicyRepository : building tag-policy-repository for tag service:[" + serviceName +"], with auditMode[" + auditModeEnum +"]");
         }
 
-        init(options);
-
         if (StringUtils.isEmpty(zoneName)) {
             this.contextEnrichers = buildContextEnrichers(options);
             this.auditPolicyEvaluators = buildAuditPolicyEvaluators(tagPolicies.getServiceConfig());
@@ -294,6 +292,8 @@ public class RangerPolicyRepository {
             this.auditPolicyEvaluators = Collections.emptyList();
         }
 
+        init(options);
+
         if (options.disableTrieLookupPrefilter) {
             policyResourceTrie      = null;
             dataMaskResourceTrie    = null;
@@ -904,9 +904,6 @@ public class RangerPolicyRepository {
     }
 
     private void init(RangerPolicyEngineOptions options) {
-        RangerServiceDefHelper serviceDefHelper = new RangerServiceDefHelper(serviceDef, false);
-        options.setServiceDefHelper(serviceDefHelper);
-
         List<RangerPolicyEvaluator> policyEvaluators = new ArrayList<>();
         List<RangerPolicyEvaluator> dataMaskPolicyEvaluators  = new ArrayList<>();
         List<RangerPolicyEvaluator> rowFilterPolicyEvaluators = new ArrayList<>();
