@@ -23,7 +23,7 @@ import java.io.IOException;
 import java.util.*;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.collections.MapUtils;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.security.UserGroupInformation;
 import org.apache.ranger.admin.client.RangerAdminClient;
 import org.apache.ranger.admin.client.RangerAdminRESTClient;
@@ -43,6 +43,7 @@ import org.apache.ranger.plugin.contextenricher.RangerTagEnricher;
 import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerRole;
 import org.apache.ranger.plugin.model.RangerServiceDef;
+import org.apache.ranger.plugin.model.validation.RangerServiceDefHelper;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequest;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequestImpl;
 import org.apache.ranger.plugin.policyengine.RangerAccessResourceImpl;
@@ -63,21 +64,23 @@ import org.slf4j.LoggerFactory;
 public class RangerBasePlugin {
 	private static final Logger LOG = LoggerFactory.getLogger(RangerBasePlugin.class);
 
-	private final RangerPluginConfig          pluginConfig;
-	private final RangerPluginContext         pluginContext;
-	private final Map<String, LogHistory>     logHistoryList = new Hashtable<>();
-	private final int                         logInterval    = 30000; // 30 seconds
-	private final DownloadTrigger             accessTrigger  = new DownloadTrigger();
-	private       PolicyRefresher             refresher;
-	private       RangerPolicyEngine          policyEngine;
-	private       RangerAuthContext           currentAuthContext;
-	private       RangerAccessResultProcessor resultProcessor;
-	private       RangerRoles                 roles;
-	private final List<RangerChainedPlugin>   chainedPlugins;
-	private final boolean                     dedupStrings;
-	private       boolean                     isUserStoreEnricherAddedImplcitly = false;
-	private       Map<String, String>         serviceConfigs;
+	private final RangerPluginConfig        pluginConfig;
+	private final RangerPluginContext       pluginContext;
+	private final Map<String, LogHistory>   logHistoryList = new Hashtable<>();
+	private final int                       logInterval    = 30000; // 30 seconds
+	private final DownloadTrigger           accessTrigger  = new DownloadTrigger();
+	private final List<RangerChainedPlugin> chainedPlugins;
+	private final boolean                   dedupStrings;
 
+	private volatile RangerPolicyEngine  policyEngine;
+	private volatile RangerAuthContext   currentAuthContext;
+	private volatile RangerRoles         roles;
+	private volatile Map<String, String> serviceConfigs;
+
+	private PolicyRefresher             refresher;
+	private RangerAccessResultProcessor resultProcessor;
+	private boolean                     isUserStoreEnricherAddedImplcitly = false;
+	private boolean                     synchronousPolicyRefresh;
 
 	public RangerBasePlugin(String serviceType, String appId) {
 		this(new RangerPluginConfig(serviceType, null, appId, null, null, null));
@@ -271,6 +274,12 @@ public class RangerBasePlugin {
 		pluginConfig.setServiceAdmins(users);
 	}
 
+	public RangerServiceDefHelper getServiceDefHelper() {
+		RangerPolicyEngine policyEngine = this.policyEngine;
+
+		return policyEngine != null ? policyEngine.getServiceDefHelper() : null;
+	}
+
 	public RangerServiceDef getServiceDef() {
 		RangerPolicyEngine policyEngine = this.policyEngine;
 
@@ -347,7 +356,6 @@ public class RangerBasePlugin {
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("==> setPolicies(" + policies + ")");
 		}
-		this.serviceConfigs = (policies != null && policies.getServiceConfig() != null) ? policies.getServiceConfig() : new HashMap<>();
 		if (pluginConfig.isEnableImplicitUserStoreEnricher() && policies != null && !ServiceDefUtil.isUserStoreEnricherPresent(policies)) {
 			String retrieverClassName = pluginConfig.get(RangerUserStoreEnricher.USERSTORE_RETRIEVER_CLASSNAME_OPTION, RangerAdminUserStoreRetriever.class.getCanonicalName());
 			String retrieverPollIntMs = pluginConfig.get(RangerUserStoreEnricher.USERSTORE_REFRESHER_POLLINGINTERVAL_OPTION, Integer.toString(60 * 1000));
@@ -361,6 +369,12 @@ public class RangerBasePlugin {
 				isUserStoreEnricherAddedImplcitly = ServiceDefUtil.addUserStoreEnricherIfNeeded(policies, retrieverClassName, retrieverPollIntMs);
 			}
 		}
+//		String isSyncPolicyRefresh = this.pluginConfig == null ? null : this.serviceConfigs.get(this.pluginConfig.getPropertyPrefix() + ".policy.refresh.synchronous");
+		String isSyncPolicyRefresh = this.pluginConfig == null ? null : (this.serviceConfigs == null ? null : this.serviceConfigs.get(this.pluginConfig.getPropertyPrefix() + ".policy.refresh.synchronous"));
+		this.synchronousPolicyRefresh = Boolean.parseBoolean(isSyncPolicyRefresh);
+		if (this.synchronousPolicyRefresh) {
+			LOG.info("synchronousPolicyRefresh = {}", this.synchronousPolicyRefresh);
+		}
 
 		// guard against catastrophic failure during policy engine Initialization or
 		try {
@@ -485,6 +499,8 @@ public class RangerBasePlugin {
 						newPolicyEngine.setTrustedProxyAddresses(pluginConfig.getTrustedProxyAddresses());
 					}
 
+                    setServiceConfigs(policies.getServiceConfig());
+
 					LOG.info("Switching policy engine from [" + getPolicyVersion() + "]");
 					this.policyEngine       = newPolicyEngine;
 					LOG.info("Switched policy engine to [" + getPolicyVersion() + "]");
@@ -558,6 +574,9 @@ public class RangerBasePlugin {
 	}
 
 	public RangerAccessResult isAccessAllowed(RangerAccessRequest request, RangerAccessResultProcessor resultProcessor) {
+		if (this.synchronousPolicyRefresh) {
+			refreshPoliciesAndTags();
+		}
 		RangerAccessResult ret          = null;
 		RangerPolicyEngine policyEngine = this.policyEngine;
 
@@ -603,6 +622,9 @@ public class RangerBasePlugin {
 	}
 
 	public Collection<RangerAccessResult> isAccessAllowed(Collection<RangerAccessRequest> requests, RangerAccessResultProcessor resultProcessor) {
+		if (this.synchronousPolicyRefresh) {
+			refreshPoliciesAndTags();
+		}
 		Collection<RangerAccessResult> ret          = null;
 		RangerPolicyEngine             policyEngine = this.policyEngine;
 
@@ -644,6 +666,9 @@ public class RangerBasePlugin {
 	}
 
 	public RangerAccessResult evalDataMaskPolicies(RangerAccessRequest request, RangerAccessResultProcessor resultProcessor) {
+		if (this.synchronousPolicyRefresh) {
+			refreshPoliciesAndTags();
+		}
 		RangerPolicyEngine policyEngine = this.policyEngine;
 		RangerAccessResult ret          = null;
 
@@ -680,6 +705,9 @@ public class RangerBasePlugin {
 	}
 
 	public RangerAccessResult evalRowFilterPolicies(RangerAccessRequest request, RangerAccessResultProcessor resultProcessor) {
+		if (this.synchronousPolicyRefresh) {
+			refreshPoliciesAndTags();
+		}
 		RangerPolicyEngine policyEngine = this.policyEngine;
 		RangerAccessResult ret          = null;
 
@@ -716,6 +744,9 @@ public class RangerBasePlugin {
 	}
 
 	public void evalAuditPolicies(RangerAccessResult result) {
+		if (this.synchronousPolicyRefresh) {
+			refreshPoliciesAndTags();
+		}
 		RangerPolicyEngine policyEngine = this.policyEngine;
 
 		if (policyEngine != null) {
@@ -738,6 +769,9 @@ public class RangerBasePlugin {
 	}
 
 	public RangerResourceACLs getResourceACLs(RangerAccessRequest request, Integer policyType) {
+		if (this.synchronousPolicyRefresh) {
+			refreshPoliciesAndTags();
+		}
 		RangerResourceACLs ret          = null;
 		RangerPolicyEngine policyEngine = this.policyEngine;
 
@@ -1037,7 +1071,7 @@ public class RangerBasePlugin {
 
 	public void refreshPoliciesAndTags() {
 		if (LOG.isDebugEnabled()) {
-			LOG.debug("==> refreshPoliciesAndTags()");
+			LOG.debug("==> refreshPoliciesAndTags(): synchronousPolicyRefresh={}", synchronousPolicyRefresh);
 		}
 
 		try {
@@ -1224,7 +1258,7 @@ public class RangerBasePlugin {
 	}
 
 	public Map<String, String> getServiceConfigs() {
-		return serviceConfigs;
+		return (serviceConfigs == null) ? Collections.emptyMap() : serviceConfigs;
 	}
 
 	protected RangerPolicyEngine getPolicyEngine() {
@@ -1370,13 +1404,13 @@ public class RangerBasePlugin {
 
 				switch (userType) {
 					case USER:
-						baseResourceACLs.setUserAccessInfo(name, chainedAccessType, finalAccessResult.getResult(), finalAccessResult.getPolicy());
+						baseResourceACLs.setUserAccessInfo(name, chainedAccessType, finalAccessResult);
 						break;
 					case GROUP:
-						baseResourceACLs.setGroupAccessInfo(name, chainedAccessType, finalAccessResult.getResult(), finalAccessResult.getPolicy());
+						baseResourceACLs.setGroupAccessInfo(name, chainedAccessType, finalAccessResult);
 						break;
 					case ROLE:
-						baseResourceACLs.setRoleAccessInfo(name, chainedAccessType, finalAccessResult.getResult(), finalAccessResult.getPolicy());
+						baseResourceACLs.setRoleAccessInfo(name, chainedAccessType, finalAccessResult);
 						break;
 					default:
 						break;
@@ -1389,6 +1423,18 @@ public class RangerBasePlugin {
 		}
 	}
 
+    private void setServiceConfigs(Map<String, String> serviceConfigs) {
+        Map<String, String> oldServiceConfigs = this.serviceConfigs;
+
+        this.serviceConfigs = serviceConfigs != null ? serviceConfigs : new HashMap<>();
+
+        RangerAuthContext authContext = this.pluginContext.getAuthContext();
+
+        if (authContext != null && !Objects.equals(oldServiceConfigs, this.serviceConfigs)) {
+            authContext.onServiceConfigsUpdate(this.serviceConfigs);
+        }
+    }
+
 	private static AuditProviderFactory getAuditProviderFactory(String serviceName) {
 		AuditProviderFactory ret = AuditProviderFactory.getInstance();
 
