@@ -70,7 +70,8 @@ public class RangerRequestExprResolver {
 
             while (matcher.find()) {
                 String expr = matcher.group(REGEX_GROUP_EXPR);
-                String val  = Objects.toString(exprValues.get(expr));
+                Object oVal = exprValues.get(expr);
+                String val  = oVal == null ? "" : Objects.toString(oVal);
 
                 matcher.appendReplacement(sb, val);
             }
@@ -98,14 +99,15 @@ public class RangerRequestExprResolver {
         String ret = str;
 
         if (hasTokens) {
-            RangerRequestScriptEvaluator scriptEvaluator = new RangerRequestScriptEvaluator(request);
             ScriptEngine                 scriptEngine    = ScriptEngineUtil.createScriptEngine(serviceType);
+            RangerRequestScriptEvaluator scriptEvaluator = new RangerRequestScriptEvaluator(request, scriptEngine, RangerRequestScriptEvaluator.needsJsonCtxEnabled(str));
             StringBuffer                 sb              = new StringBuffer();
             Matcher                      matcher         = PATTERN.matcher(str);
 
             while (matcher.find()) {
                 String expr = matcher.group(REGEX_GROUP_EXPR);
-                String val  = Objects.toString(scriptEvaluator.evaluateScript(scriptEngine, expr));
+                Object oVal = scriptEvaluator.evaluateScript(expr);
+                String val  = oVal == null ? "" : Objects.toString(oVal);
 
                 matcher.appendReplacement(sb, val);
             }
