@@ -48,7 +48,7 @@ public class XMLUtils {
 		try (InputStream input = getFileInputStream(configFileName)) {
 			loadConfig(input, properties);
 		} catch (Exception e) {
-			LOG.error("Error loading : ", e);
+			LOG.error("Error loading : {}", configFileName, e);
 		}
 	}
 
@@ -132,6 +132,10 @@ public class XMLUtils {
 			}
 		}
 
+		if (ret == null) {
+			throw new FileNotFoundException(path + " is not found");
+		}
+
 		return ret;
 	}
 
