@@ -37,7 +37,7 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.security.SecureClientLogin;
 import org.apache.http.HttpEntity;
 import org.apache.http.client.methods.HttpPost;
@@ -59,8 +59,6 @@ import org.apache.solr.common.cloud.ZkConfigManager;
 import org.noggit.JSONParser;
 import org.noggit.ObjectBuilder;
 
-import com.google.protobuf.TextFormat.ParseException;
-
 public class SolrCollectionBootstrapper extends Thread {
 
 	private static final Logger logger = Logger
@@ -435,7 +433,7 @@ public class SolrCollectionBootstrapper extends Thread {
 	}
 
 	@SuppressWarnings("unchecked")
-	private List<String> getCollections() throws IOException, ParseException {
+	private List<String> getCollections() throws IOException {
 		try {
 			CollectionAdminRequest.List colListReq = new CollectionAdminRequest.List();
 			CollectionAdminResponse response = colListReq.process(solrClient);
