@@ -46,8 +46,8 @@ import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.lang.ArrayUtils;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.ArrayUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.fs.permission.FsAction;
@@ -1452,182 +1452,3 @@ class AuthzContext {
 		return lastResult;
 	}
 }
-
-class RangerHdfsAuditHandler extends RangerDefaultAuditHandler {
-	private static final Logger LOG = LoggerFactory.getLogger(RangerHdfsAuditHandler.class);
-
-	private boolean         isAuditEnabled = false;
-	private AuthzAuditEvent auditEvent     = null;
-	private final String pathToBeValidated;
-	private final boolean auditOnlyIfDenied;
-
-	private final String      hadoopModuleName;
-	private final Set<String> excludeUsers;
-	private final String      callerContext;
-
-	public RangerHdfsAuditHandler(String pathToBeValidated, boolean auditOnlyIfDenied, String hadoopModuleName, Set<String> excludedUsers, String callerContext) {
-		this.pathToBeValidated = pathToBeValidated;
-		this.auditOnlyIfDenied = auditOnlyIfDenied;
-		this.hadoopModuleName  = hadoopModuleName;
-		this.excludeUsers      = excludedUsers;
-		this.callerContext     = callerContext;
-	}
-
-	@Override
-	public void processResult(RangerAccessResult result) {
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerHdfsAuditHandler.logAudit(" + result + ")");
-		}
-
-		if (result != null) {
-			isAuditEnabled = result.getIsAudited();
-
-			if (auditEvent == null) {
-				auditEvent = super.getAuthzEvents(result);
-			}
-
-			if (auditEvent != null) {
-				RangerAccessRequest request = result.getAccessRequest();
-				RangerAccessResource resource = request.getResource();
-				String resourcePath = resource != null ? resource.getAsString() : null;
-
-				// Overwrite fields in original auditEvent
-				auditEvent.setEventTime(request.getAccessTime() != null ? request.getAccessTime() : new Date());
-				auditEvent.setAccessType(request.getAction());
-				auditEvent.setResourcePath(this.pathToBeValidated);
-				auditEvent.setResultReason(resourcePath);
-
-				auditEvent.setAccessResult((short) (result.getIsAllowed() ? 1 : 0));
-				auditEvent.setPolicyId(result.getPolicyId());
-				auditEvent.setPolicyVersion(result.getPolicyVersion());
-				setRequestData();
-
-				auditEvent.setAction(getAccessType(request.getAccessType()));
-				auditEvent.setAdditionalInfo(getAdditionalInfo(request));
-
-				Set<String> tags = getTags(request);
-				if (tags != null) {
-					auditEvent.setTags(tags);
-				}
-			}
-		}
-
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerHdfsAuditHandler.logAudit(" + result + "): " + auditEvent);
-		}
-	}
-
-	@Override
-	public 	String getAdditionalInfo(RangerAccessRequest request) {
-		String        additionalInfo = super.getAdditionalInfo(request);
-		Map addInfoMap = JsonUtils.jsonToMapStringString(additionalInfo);
-		if(addInfoMap == null || addInfoMap.isEmpty()) {
-		      addInfoMap = new HashMap<String,String>();
-		}
-		String accessTypes = getAccessTypesAsString(request);
-		if (addInfoMap != null && accessTypes != null) {
-			addInfoMap.put("accessTypes", "[" + accessTypes + "]");
-		}
-		return JsonUtils.mapToJson(addInfoMap);
-	}
-
-	public void logHadoopEvent(String path, FsAction action, boolean accessGranted) {
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerHdfsAuditHandler.logHadoopEvent(" + path + ", " + action + ", " + accessGranted + ")");
-		}
-
-		if(auditEvent != null) {
-			auditEvent.setResultReason(path);
-			auditEvent.setAccessResult((short) (accessGranted ? 1 : 0));
-			auditEvent.setAclEnforcer(hadoopModuleName);
-			auditEvent.setPolicyId(-1);
-
-			String accessType = (action == null) ? null : action.toString();
-
-			if (StringUtils.isBlank(auditEvent.getAccessType())) { // retain existing value
-				auditEvent.setAccessType(accessType);
-			}
-
-			if (accessType != null) {
-				auditEvent.setAction(getAccessType(accessType));
-			}
-
-			setRequestData();
-		}
-
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerHdfsAuditHandler.logHadoopEvent(" + path + ", " + action + ", " + accessGranted + "): " + auditEvent);
-		}
-	}
-
-	public void flushAudit() {
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerHdfsAuditHandler.flushAudit(" + isAuditEnabled + ", " + auditEvent + ")");
-		}
-
-		if(isAuditEnabled && auditEvent != null && !StringUtils.isEmpty(auditEvent.getAccessType())) {
-			String username = auditEvent.getUser();
-			String accessType = auditEvent.getAccessType();
-
-			boolean skipLog = (username != null && excludeUsers != null && excludeUsers.contains(username))
-								|| (auditOnlyIfDenied && auditEvent.getAccessResult() != 0)
-								|| (ACCESS_TYPE_MONITOR_HEALTH.equals(accessType));
-
-			if (! skipLog) {
-				super.logAuthzAudit(auditEvent);
-			}
-		}
-
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerHdfsAuditHandler.flushAudit(" + isAuditEnabled + ", " + auditEvent + ")");
-		}
-	}
-
-	private String getAccessType(String accessType) {
-		String ret = accessType;
-
-		switch (accessType) {
-			case READ_EXECUTE_PERM:
-				ret = READ_ACCCESS_TYPE;
-				break;
-			case WRITE_EXECUTE_PERM:
-			case READ_WRITE_PERM:
-			case ALL_PERM:
-				ret = WRITE_ACCCESS_TYPE;
-				break;
-			default:
-				break;
-		}
-		return ret.toLowerCase();
-	}
-
-	private String getAccessTypesAsString(RangerAccessRequest request) {
-		String             ret         = null;
-		Set<String>        accessTypes = RangerAccessRequestUtil.getAllRequestedAccessTypes(request);
-
-		if (CollectionUtils.isNotEmpty(accessTypes)) {
-			try {
-				ret = getFormattedAccessType(accessTypes);
-			} catch (Throwable t) {
-				LOG.error("getAccessTypesAsString(): failed to get accessTypes from context", t);
-			}
-		} else {
-			ret = request.getAccessType();
-		}
-		return ret;
-	}
-
-	private String getFormattedAccessType(Set<String> accessTypes) {
-		String ret = null;
-		if (CollectionUtils.isNotEmpty(accessTypes)) {
-			ret = String.join(", ", accessTypes);
-		}
-		return ret;
-	}
-
-	private void setRequestData(){
-		if (StringUtils.isNotBlank(auditEvent.getAccessType()) && StringUtils.isNotBlank(callerContext)) {
-			auditEvent.setRequestData(auditEvent.getAccessType() + "/" + callerContext);
-		}
-	}
-}
