@@ -355,8 +355,21 @@ class RangerClient:
     def purge_records(self, record_type, retention_days):
         return self.client_http.call_api(RangerClient.PURGE_RECORDS, { 'type': record_type, 'retentionDays': retention_days})
 
-
-
+    def set_log_level(self, logger_name, log_level):
+        """
+        Sets the log level for a specific class or package.
+        This operation requires ROLE_SYS_ADMIN role.
+        
+        :param logger_name: The name of the logger (class or package name)
+        :param log_level: The log level to set (TRACE, DEBUG, INFO, WARN, ERROR, OFF)
+        :return: A message indicating the result of the operation
+        :raises: RangerServiceException if the operation fails
+        """
+        request_data = {
+            'loggerName': logger_name,
+            'logLevel': log_level
+        }
+        return self.client_http.call_api(RangerClient.SET_LOG_LEVEL, request_data=request_data)
 
 
     # URIs
@@ -401,6 +414,7 @@ class RangerClient:
     URI_PLUGIN_INFO         = URI_BASE + "/plugins/info"
     URI_POLICY_DELTAS       = URI_BASE + "/server/policydeltas"
     URI_PURGE_RECORDS       = URI_BASE + "/server/purge/records"
+    URI_LOGGERS_SET_LEVEL   = "service/admin/set-logger-level"
 
     # APIs
     CREATE_SERVICEDEF         = API(URI_SERVICEDEF, HttpMethod.POST, HTTPStatus.OK)
@@ -469,6 +483,7 @@ class RangerClient:
     DELETE_POLICY_DELTAS      = API(URI_POLICY_DELTAS, HttpMethod.DELETE, HTTPStatus.NO_CONTENT)
     PURGE_RECORDS             = API(URI_PURGE_RECORDS, HttpMethod.DELETE, HTTPStatus.OK)
 
+    SET_LOG_LEVEL             = API(URI_LOGGERS_SET_LEVEL, HttpMethod.POST, HTTPStatus.OK)
 
 
 class HadoopSimpleAuth(AuthBase):
