@@ -14,7 +14,7 @@
 package org.apache.ranger.services.trino.client;
 
 import org.apache.commons.io.FilenameUtils;
-import org.apache.commons.lang.StringEscapeUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.ranger.plugin.client.BaseClient;
 import org.apache.ranger.plugin.client.HadoopConfigHolder;
 import org.apache.ranger.plugin.client.HadoopException;
@@ -211,7 +211,7 @@ public class TrinoClient
             try {
                 if (needle != null && !needle.isEmpty() && !needle.equals("*")) {
                     // Cannot use a prepared statement for this as trino does not support that
-                    sql += " LIKE '" + StringEscapeUtils.escapeSql(needle) + "%'";
+                    sql += " LIKE '" + escapeSql(needle) + "%'";
                 }
 
                 stat = con.createStatement();
@@ -285,11 +285,11 @@ public class TrinoClient
             try {
                 if (catalogs != null && !catalogs.isEmpty()) {
                     for (String catalog : catalogs) {
-                        sql = "SHOW SCHEMAS FROM \"" + StringEscapeUtils.escapeSql(catalog) + "\"";
+                        sql = "SHOW SCHEMAS FROM \"" + escapeSql(catalog) + "\"";
 
                         try {
                             if (needle != null && !needle.isEmpty() && !needle.equals("*")) {
-                                sql += " LIKE '" + StringEscapeUtils.escapeSql(needle) + "%'";
+                                sql += " LIKE '" + escapeSql(needle) + "%'";
                             }
 
                             stat = con.createStatement();
@@ -383,11 +383,11 @@ public class TrinoClient
                 try {
                     for (String catalog : catalogs) {
                         for (String schema : schemas) {
-                            sql = "SHOW tables FROM \"" + StringEscapeUtils.escapeSql(catalog) + "\".\"" + StringEscapeUtils.escapeSql(schema) + "\"";
+                            sql = "SHOW tables FROM \"" + escapeSql(catalog) + "\".\"" + escapeSql(schema) + "\"";
 
                             try {
                                 if (needle != null && !needle.isEmpty() && !needle.equals("*")) {
-                                    sql += " LIKE '" + StringEscapeUtils.escapeSql(needle) + "%'";
+                                    sql += " LIKE '" + escapeSql(needle) + "%'";
                                 }
 
                                 stat = con.createStatement();
@@ -489,9 +489,9 @@ public class TrinoClient
                     for (String catalog : catalogs) {
                         for (String schema : schemas) {
                             for (String table : tables) {
-                                sql = "SHOW COLUMNS FROM \"" + StringEscapeUtils.escapeSql(catalog) + "\"." +
-                                    "\"" + StringEscapeUtils.escapeSql(schema) + "\"." +
-                                    "\"" + StringEscapeUtils.escapeSql(table) + "\"";
+                                sql = "SHOW COLUMNS FROM \"" + escapeSql(catalog) + "\"." +
+                                    "\"" + escapeSql(schema) + "\"." +
+                                    "\"" + escapeSql(table) + "\"";
 
                                 try {
                                     stat = con.createStatement();
@@ -667,4 +667,12 @@ public class TrinoClient
             LOG.error("Unable to close ResultSet", e);
         }
     }
+
+    private static String escapeSql(String str)
+    {
+        if (str == null) {
+            return null;
+        }
+        return StringUtils.replace(str, "'", "''");
+    }
 }
