@@ -36,7 +36,7 @@ import javax.naming.ldap.Rdn;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.ranger.amazon.cloudwatch.CloudWatchAccessAuditsService;
 import org.apache.ranger.authorization.hadoop.config.RangerAdminConfig;
 import org.apache.ranger.common.AppConstants;
@@ -1023,6 +1023,14 @@ public class AssetMgr extends AssetMgrBase {
 		}
 	}
 
+
+	public void doDeleteXXPluginInfo(Long id) {
+		XXPluginInfo xObj = rangerDaoManager.getXXPluginInfo().getById(id);
+		if (xObj != null) {
+			rangerDaoManager.getXXPluginInfo().remove(xObj.getId());
+		}
+	}
+
 	private String getRemoteAddress(final HttpServletRequest request) {
 		String ret = null;
 
