@@ -22,9 +22,7 @@
 
 import java.util.List;
 
-import javax.xml.bind.annotation.XmlRootElement;
 
-@XmlRootElement
 public abstract class VList extends ViewBaseBean implements
 	java.io.Serializable {
     private static final long serialVersionUID = 1L;
