@@ -40,7 +40,7 @@ import javax.ws.rs.QueryParam;
 import javax.ws.rs.WebApplicationException;
 import javax.ws.rs.core.Context;
 
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.ranger.admin.client.datatype.RESTResponse;
 import org.apache.ranger.biz.AssetMgr;
 import org.apache.ranger.biz.RangerBizUtil;
@@ -628,6 +628,8 @@ public class AssetREST {
 				"Request Data", StringUtil.VALIDATION_TEXT);
 		searchUtil.extractString(request, searchCriteria, "resourcePath",
 				"Resource Name", StringUtil.VALIDATION_TEXT);
+		searchUtil.extractString(request, searchCriteria, "excludeResourceName",
+				"Exclude Resource Name", StringUtil.VALIDATION_TEXT);
 		searchUtil.extractString(request, searchCriteria, "clientIP",
 				"Client IP", StringUtil.VALIDATION_TEXT);
 		searchUtil.extractString(request, searchCriteria, "resourceType",
