@@ -25,6 +25,7 @@ import arrayMutators from "final-form-arrays";
 import { FieldArray } from "react-final-form-arrays";
 import Select from "react-select";
 import AsyncSelect from "react-select/async";
+import AsyncCreatableSelect from "react-select/async-creatable";
 import { RegexValidation, additionalServiceConfigs } from "Utils/XAEnums";
 import { fetchApi } from "Utils/fetchAPI";
 import ServiceAuditFilter from "./ServiceAuditFilter";
@@ -675,7 +676,7 @@ class ServiceForm extends Component {
                 key={"configs." + additionalConfig.name + index}
                 id={"configs." + additionalConfig.name}
                 data-cy={"configs." + additionalConfig.name}
-                component={this.AsyncSelectField}
+                component={this.AsyncCreatableSelectField}
                 loadOptions={
                   additionalConfig.type == "user"
                     ? this.fetchUsers
@@ -991,6 +992,10 @@ class ServiceForm extends Component {
     <AsyncSelect {...input} {...rest} cacheOptions />
   );
 
+  AsyncCreatableSelectField = ({ input, ...rest }) => (
+    <AsyncCreatableSelect {...input} {...rest} />
+  );
+
   fetchUsers = async (inputValue) => {
     let params = { name: inputValue || "", isVisible: 1 };
     let op = [];
@@ -1035,16 +1040,16 @@ class ServiceForm extends Component {
 
     try {
       const roleResp = await fetchApi({
-        url: "roles/roles",
+        url: "roles/lookup/roles/names",
         params: params
       });
-      op = roleResp.data?.roles;
+      op = roleResp.data?.vXStrings;
     } catch (error) {
       console.error(`Error occurred while fetching Roles ! ${error}`);
     }
 
     return map(op, function (obj) {
-      return { label: obj.name, value: obj.name };
+      return { label: obj.value, value: obj.value };
     });
   };
   ServiceDefnBreadcrumb = () => {
