@@ -38,7 +38,7 @@ import { fetchApi } from "Utils/fetchAPI";
 import usePrompt from "Hooks/usePrompt";
 import { RegexValidation } from "Utils/XAEnums";
 
-const initialState = {
+const INITIAL_STATE = {
   loader: true,
   roleInfo: {},
   selectedUser: [],
@@ -99,9 +99,10 @@ function reducer(state, action) {
 
 function RoleForm() {
   const params = useParams();
-  const { state } = useLocation();
   const navigate = useNavigate();
-  const [roleFormState, dispatch] = useReducer(reducer, initialState);
+  const { state: navigateState } = useLocation();
+
+  const [state, dispatch] = useReducer(reducer, INITIAL_STATE);
   const {
     loader,
     roleInfo,
@@ -110,8 +111,10 @@ function RoleForm() {
     selectedGroup,
     preventUnBlock,
     blockUI
-  } = roleFormState;
+  } = state;
+
   const toastId = React.useRef(null);
+
   useEffect(() => {
     if (params?.roleID) {
       fetchRoleData(params.roleID);
@@ -133,6 +136,7 @@ function RoleForm() {
       return findIndex(selectedUser, data) === -1;
     }
   };
+
   const filterGroupOp = (data, formVal) => {
     if (formVal && formVal.groups) {
       let groupSelectedData = formVal.groups.map((m) => {
@@ -143,6 +147,7 @@ function RoleForm() {
       return findIndex(selectedGroup, data) === -1;
     }
   };
+
   const filterRoleOp = (data, formVal) => {
     if (formVal && formVal.roles) {
       let roleSelectedData = formVal.roles.map((m) => {
@@ -231,14 +236,20 @@ function RoleForm() {
           method: "post",
           data: formData
         });
-        let tblpageData = {};
-        if (state && state != null) {
-          tblpageData = state.tblpageData;
-          if (state.tblpageData.pageRecords % state.tblpageData.pageSize == 0) {
-            tblpageData["totalPage"] = state.tblpageData.totalPage + 1;
+        let tablePageData = {};
+        if (navigateState && navigateState != null) {
+          tablePageData = navigateState.tablePageData;
+          if (
+            navigateState.tablePageData.pageRecords %
+              navigateState.tablePageData.pageSize ==
+            0
+          ) {
+            tablePageData["totalPage"] =
+              navigateState.tablePageData.totalPage + 1;
           } else {
-            if (tblpageData !== undefined) {
-              tblpageData["totalPage"] = state.tblpageData.totalPage;
+            if (tablePageData !== undefined) {
+              tablePageData["totalPage"] =
+                navigateState.tablePageData.totalPage;
             }
           }
         }
@@ -250,7 +261,7 @@ function RoleForm() {
         navigate("/users/roletab", {
           state: {
             showLastPage: true,
-            addPageData: tblpageData
+            addPageData: tablePageData
           }
         });
       } catch (error) {
@@ -412,6 +423,7 @@ function RoleForm() {
     }
     return formValueObj;
   };
+
   const validateForm = (values) => {
     const errors = {};
     if (!values.name) {
