@@ -18,19 +18,18 @@
  */
 
 import React, { Component } from "react";
-import UserFormComp from "Views/UserGroupRoleListing/users_details/UserFormComp";
-import { commonBreadcrumb } from "../../../utils/XAUtils";
+import UserForm from "Views/UserGroupRoleListing/users_details/UserForm";
+import { commonBreadcrumb } from "Utils/XAUtils";
 
 class AddUserView extends Component {
   render() {
     return (
       <>
-        {/* {commonBreadcrumb(["Users", "UserCreate"])} */}
         <div className="header-wraper">
           <h3 className="wrap-header bold">User Detail</h3>
           {commonBreadcrumb(["Users", "UserCreate"])}
         </div>
-        <UserFormComp />
+        <UserForm />
       </>
     );
   }
