@@ -19,7 +19,7 @@
 
 package org.apache.ranger.tagsync.process;
 
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.security.SecureClientLogin;
 import org.apache.ranger.tagsync.ha.TagSyncHAInitializerImpl;
@@ -102,6 +102,7 @@ public class TagSyncConfig extends Configuration {
 	public  static final int  DEFAULT_TAGSYNC_ATLASREST_SOURCE_ENTITIES_BATCH_SIZE = 10000;
 	private static final long DEFAULT_TAGSYNC_FILESOURCE_MOD_TIME_CHECK_INTERVAL = 60000;
 	private static final long DEFAULT_TAGSYNC_SOURCE_RETRY_INITIALIZATION_INTERVAL = 10000;
+	private static final long DEFAULT_TAGSYNC_HA_PASSIVE_SLEEP_INTERVAL            = 5000;
 
 	private static final String AUTH_TYPE = "hadoop.security.authentication";
 	private static final String NAME_RULES = "hadoop.security.auth_to_local";
@@ -228,6 +229,10 @@ public class TagSyncConfig extends Configuration {
 		return TagSyncHAInitializerImpl.getInstance(TagSyncConfig.getInstance()).isActive();
 	}
 
+	public static long getTagSyncHAPassiveSleepInterval() {
+		return DEFAULT_TAGSYNC_HA_PASSIVE_SLEEP_INTERVAL;
+	}
+
 	@Override
 	public String toString() {
 		StringBuilder sb = new StringBuilder();
