@@ -32,7 +32,7 @@ import javax.servlet.http.HttpServletResponse;
 import javax.ws.rs.core.Cookie;
 import javax.ws.rs.core.NewCookie;
 
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.security.UserGroupInformation;
 import org.apache.ranger.admin.client.datatype.RESTResponse;
 import org.apache.ranger.plugin.util.RangerRESTClient;
@@ -98,7 +98,7 @@ public class TagAdminRESTSink implements TagSink, Runnable {
 		}
 
 		if (StringUtils.isNotBlank(restUrl)) {
-			tagRESTClient = new RangerRESTClient(restUrl, sslConfigFile, TagSyncConfig.getInstance());
+			tagRESTClient = new RangerRESTClient(restUrl, sslConfigFile, TagSyncConfig.getInstance(), "ranger.tagsync");
 			if (!isKerberized) {
 				tagRESTClient.setBasicAuthInfo(userName, password);
 			}
@@ -391,11 +391,21 @@ public class TagAdminRESTSink implements TagSink, Runnable {
 							Thread.sleep(rangerAdminConnectionCheckInterval);
 						}
 					} while (doRetry);
-
 				} catch (InterruptedException exception) {
 					LOG.error("Interrupted..: ", exception);
 					return;
 				}
+			} else {
+				try {
+					long sleepInterval = TagSyncConfig.getTagSyncHAPassiveSleepInterval();
+					LOG.debug("Sleeping for [{}] milliSeconds as this server is running in passive mode", sleepInterval);
+					Thread.sleep(sleepInterval);
+				} catch (InterruptedException interrupted) {
+					LOG.error("Interrupted..: ", interrupted);
+					// preserve interrupt status for caller of the thread
+					Thread.currentThread().interrupt();
+					return;
+				}
 			}
 		}
 
