@@ -25,7 +25,7 @@ import org.apache.atlas.notification.NotificationConsumer;
 import org.apache.atlas.notification.NotificationInterface;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.collections.MapUtils;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.ranger.authorization.utils.JsonUtils;
 import org.apache.ranger.plugin.util.ServiceTags;
 import org.apache.ranger.tagsync.model.AbstractTagSource;
@@ -251,7 +251,18 @@ public class AtlasTagSource extends AbstractTagSource {
 						return;
 					}
 				}
-			  }
+			} else {
+				try {
+					long sleepInterval = TagSyncConfig.getTagSyncHAPassiveSleepInterval();
+					LOG.debug("Sleeping for [{}] milliSeconds as this server is running in passive mode", sleepInterval);
+					Thread.sleep(sleepInterval);
+				} catch (InterruptedException interrupted) {
+					LOG.error("Interrupted..: ", interrupted);
+					// preserve interrupt status for caller of the thread
+					Thread.currentThread().interrupt();
+					return;
+				}
+			}
 			}
 		}
 
