@@ -31,7 +31,6 @@ import org.apache.commons.configuration2.PropertiesConfiguration;
 import org.apache.commons.configuration2.builder.FileBasedConfigurationBuilder;
 import org.apache.commons.configuration2.builder.fluent.Parameters;
 import org.apache.commons.configuration2.ex.ConfigurationException;
-import org.apache.commons.lang.NullArgumentException;
 
 public class LdapConfig {
 
@@ -79,9 +78,6 @@ public class LdapConfig {
     private static final String LGSYNC_GROUP_SEARCH_ENABLED = "ranger.usersync.group.searchenabled";
     private static final boolean DEFAULT_LGSYNC_GROUP_SEARCH_ENABLED = false;
 
-    private static final String LGSYNC_GROUP_USER_MAP_SYNC_ENABLED = "ranger.usersync.group.usermapsyncenabled";
-    private static final boolean DEFAULT_LGSYNC_GROUP_USER_MAP_SYNC_ENABLED = false;
-
     private static final String LGSYNC_GROUP_SEARCH_BASE = "ranger.usersync.group.searchbase";
 
     private static final String LGSYNC_GROUP_SEARCH_SCOPE = "ranger.usersync.group.searchscope";
@@ -186,7 +182,7 @@ public class LdapConfig {
     public String getLdapUrl() throws Throwable {
         String val = prop.getProperty(LGSYNC_LDAP_URL);
         if (val == null || val.trim().isEmpty()) {
-            throw new NullArgumentException(LGSYNC_LDAP_URL);
+            throw new IllegalArgumentException(LGSYNC_LDAP_URL + " must not be null or empty");
         }
         return val;
     }
@@ -195,7 +191,7 @@ public class LdapConfig {
     public String getLdapBindDn() throws Throwable {
         String val = prop.getProperty(LGSYNC_LDAP_BIND_DN);
         if (val == null || val.trim().isEmpty()) {
-            throw new NullArgumentException(LGSYNC_LDAP_BIND_DN);
+            throw new IllegalArgumentException(LGSYNC_LDAP_BIND_DN + " must not be null or empty");
         }
         return val;
     }
@@ -315,17 +311,6 @@ public class LdapConfig {
         return groupSearchEnabled;
     }
 
-    public boolean isGroupUserMapSyncEnabled() {
-        boolean groupUserMapSyncEnabled;
-        String val = prop.getProperty(LGSYNC_GROUP_USER_MAP_SYNC_ENABLED);
-        if (val == null || val.trim().isEmpty()) {
-            groupUserMapSyncEnabled = DEFAULT_LGSYNC_GROUP_USER_MAP_SYNC_ENABLED;
-        } else {
-            groupUserMapSyncEnabled = Boolean.valueOf(val);
-        }
-        return groupUserMapSyncEnabled;
-    }
-
     public String getGroupSearchBase() {
         String val = prop.getProperty(LGSYNC_GROUP_SEARCH_BASE);
         return val;
